# Tools

```{eval-rst}
.. module:: drvi.utils.tools
.. currentmodule:: drvi.utils

.. autosummary::
    :nosignatures:
    :toctree: generated

    tools.set_latent_dimension_stats
    tools.traverse_latent
    tools.calculate_differential_vars
    tools.get_split_effects
    tools.iterate_on_top_differential_vars
```
